@@ -56,6 +56,7 @@ from ormar.fields import (
     LargeBinary,
     ManyToMany,
     ManyToManyField,
+    SmallInteger,
     String,
     Text,
     Time,
@@ -76,10 +77,11 @@ class UndefinedType:  # pragma no cover
 
 Undefined = UndefinedType()
 
-__version__ = "0.10.15"
+__version__ = "0.10.17"
 __all__ = [
     "Integer",
     "BigInteger",
+    "SmallInteger",
     "Boolean",
     "Time",
     "Text",
