@@ -17,6 +17,7 @@ from ormar.fields.model_fields import (
     Integer,
     JSON,
     LargeBinary,
+    SmallInteger,
     String,
     Text,
     Time,
@@ -29,6 +30,7 @@ from ormar.fields.through_field import Through, ThroughField
 __all__ = [
     "Decimal",
     "BigInteger",
+    "SmallInteger",
     "Boolean",
     "Date",
     "DateTime",
