@@ -36,8 +36,8 @@ from ormar.models.helpers import (
     expand_reverse_relationships,
     extract_annotations_and_default_vals,
     get_potential_fields,
-    get_pydantic_base_orm_config,
     get_pydantic_field,
+    merge_or_generate_pydantic_config,
     meta_field_not_set,
     populate_choices_validators,
     populate_default_options_values,
@@ -552,7 +552,7 @@ class ModelMetaclass(pydantic.main.ModelMetaclass):
         :param attrs: class namespace
         :type attrs: Dict
         """
-        attrs["Config"] = get_pydantic_base_orm_config()
+        merge_or_generate_pydantic_config(attrs=attrs, name=name)
         attrs["__name__"] = name
         attrs, model_fields = extract_annotations_and_default_vals(attrs)
         for base in reversed(bases):
@@ -580,9 +580,11 @@ class ModelMetaclass(pydantic.main.ModelMetaclass):
                 populate_meta_sqlalchemy_table_if_required(new_model.Meta)
                 expand_reverse_relationships(new_model)
                 # TODO: iterate only related fields
-                for name, field in new_model.Meta.model_fields.items():
+                for field_name, field in new_model.Meta.model_fields.items():
                     register_relation_in_alias_manager(field=field)
-                    add_field_descriptor(name=name, field=field, new_model=new_model)
+                    add_field_descriptor(
+                        name=field_name, field=field, new_model=new_model
+                    )
 
                 if (
                     new_model.Meta.pkname
@@ -640,10 +642,7 @@ class ModelMetaclass(pydantic.main.ModelMetaclass):
                     model=field.to,
                     access_chain=item,
                 )
-            else:
-                return FieldAccessor(
-                    source_model=cast(Type["Model"], self),
-                    field=field,
-                    access_chain=item,
-                )
+            return FieldAccessor(
+                source_model=cast(Type["Model"], self), field=field, access_chain=item,
+            )
         return object.__getattribute__(self, item)
